@@ -44,6 +44,7 @@ class Command(BaseCommand):
         invoice_obj.order_number = invoice.order_number
         invoice_obj.date = invoice.invoice_date
         invoice_obj.amount = invoice.amount
+        invoice_obj.credit = invoice.credit
 
         invoice_obj.save()
         print(invoice_obj)
@@ -77,6 +78,13 @@ class Command(BaseCommand):
                     'sum': line.sum,
                 },
             )
+            if line_obj.sum != line.sum:
+                line_obj.quantity = line.quantity
+                line_obj.description = line.description
+                line_obj.name = line.name
+                line_obj.price = line.price
+                line_obj.sum = line.sum
+                line_obj.save()
 
             for serial in line.serials:
                 serial_obj = SerialNumber(line=line_obj, serial=serial)
@@ -85,7 +93,7 @@ class Command(BaseCommand):
 
     def handle(self, *args, **options):
         if os.path.isfile(options['file'][0]):
-            return self.load(options['file'][0])
+            self.load(options['file'][0])
         elif os.path.isdir(options['file'][0]):
             for file in os.scandir(options['file'][0]):
                 if os.path.isfile(file):
